@@ -242,6 +242,7 @@ func (l configLoader) applyConfigDefaults() error {
 		"watch":                                false,
 		"resourceDir":                          "resources",
 		"publishDir":                           "public",
+		"publishDirOrig":                       "public",
 		"themesDir":                            "themes",
 		"buildDrafts":                          false,
 		"buildFuture":                          false,
@@ -417,12 +418,18 @@ func (l configLoader) collectModules(modConfig modules.Config, v1 config.Provide
 	// Avoid recreating these later.
 	v1.Set("allModules", moduleConfig.ActiveModules)
 
+	// We want to watch these for changes and trigger rebuild on version
+	// changes etc.
 	if moduleConfig.GoModulesFilename != "" {
-		// We want to watch this for changes and trigger rebuild on version
-		// changes etc.
+
 		configFilenames = append(configFilenames, moduleConfig.GoModulesFilename)
 	}
 
+	if moduleConfig.GoWorkspaceFilename != "" {
+		configFilenames = append(configFilenames, moduleConfig.GoWorkspaceFilename)
+
+	}
+
 	return moduleConfig.ActiveModules, configFilenames, err
 }
 
